@@ -302,6 +302,9 @@ namespace libtorrent
 	// returns true if this socket is an SSL socket
 	bool is_ssl(socket_type const& s);
 
+	// returns true if this is a uTP socket
+	bool is_utp(socket_type const& s);
+
 	// assuming the socket_type s is an ssl socket, make sure it
 	// verifies the hostname in its SSL handshake
 	void setup_ssl_hostname(socket_type& s, std::string const& hostname, error_code& ec);
