@@ -2048,7 +2048,6 @@ namespace libtorrent
 				lazy_pieces[lazy_piece++] = i;
 			}
 			TORRENT_ASSERT(lazy_piece == num_lazy_pieces);
-			lazy_piece = 0;
 		}
 
 		const int packet_size = (num_pieces + 7) / 8 + 5;
@@ -3100,7 +3099,7 @@ namespace libtorrent
 		{
 			TORRENT_ASSERT(m_sent_handshake);
 			m_statistics.received_bytes(0, bytes_transferred);
-			bytes_transferred = 0;
+//			bytes_transferred = 0;
   			if (!t)
 			{
 				TORRENT_ASSERT(!packet_finished()); // TODO
