@@ -72,13 +72,13 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <unistd.h>
 #include <fcntl.h> // for F_LOG2PHYS
 #include <sys/types.h>
-#include <sys/statvfs.h>
 #include <errno.h>
 #include <dirent.h>
 
 #ifdef TORRENT_LINUX
 // linux specifics
 
+#include <sys/statvfs.h>
 #include <sys/ioctl.h>
 #include <linux/types.h>
 #ifdef HAVE_LINUX_FIEMAP_H
@@ -1082,7 +1082,7 @@ namespace libtorrent
 				0, // start offset
 				0, // length (0 = until EOF)
 				getpid(), // owner
-				(mode & write_only) ? F_WRLCK : F_RDLCK, // lock type
+				short((mode & write_only) ? F_WRLCK : F_RDLCK), // lock type
 				SEEK_SET // whence
 			};
 			if (fcntl(m_fd, F_SETLK, &l) != 0)
@@ -1979,7 +1979,12 @@ typedef struct _FILE_ALLOCATED_RANGE_BUFFER {
 			// only allocate the space if the file
 			// is not fully allocated
 			DWORD high_dword = 0;
-			offs.LowPart = GetCompressedFileSize(m_path.c_str(), &high_dword);
+#if TORRENT_USE_WSTRING
+#define GetCompressedFileSize_ GetCompressedFileSizeW
+#else
+#define GetCompressedFileSize_ GetCompressedFileSizeA
+#endif
+			offs.LowPart = GetCompressedFileSize_(m_path.c_str(), &high_dword);
 			offs.HighPart = high_dword;
 			ec.assign(GetLastError(), get_system_category());
 			if (ec) return false;
