@@ -420,7 +420,7 @@ void http_connection::on_timeout(boost::weak_ptr<http_connection> p
 		else
 		{
 			c->callback(asio::error::timed_out);
-			c->close();
+			c->close(true);
 		}
 		return;
 	}
@@ -436,7 +436,7 @@ void http_connection::on_timeout(boost::weak_ptr<http_connection> p
 	c->m_timer.async_wait(boost::bind(&http_connection::on_timeout, p, _1));
 }
 
-void http_connection::close()
+void http_connection::close(bool force)
 {
 	if (m_abort) return;
 
@@ -445,7 +445,10 @@ void http_connection::close()
 	m_resolver.cancel();
 	m_limiter_timer.cancel(ec);
 
-	async_shutdown(m_sock, shared_from_this());
+	if (force)
+		m_sock.close(ec);
+	else
+		async_shutdown(m_sock, shared_from_this());
 
 	m_hostname.clear();
 	m_port.clear();
